@@ -4,6 +4,7 @@ from __future__ import annotations
 
 import difflib
 import json
+import shlex
 import signal
 import sys
 import tempfile
@@ -13,23 +14,25 @@ from collections.abc import Sequence  # noqa: TC003  # pydantic needs it
 from enum import IntEnum
 from io import TextIOBase
 from pathlib import Path
-from typing import TYPE_CHECKING, Any, ClassVar, Optional, Union, cast
+from typing import TYPE_CHECKING, Any, ClassVar, Optional, TypeAlias, Union, cast
 from urllib.parse import ParseResult, urlparse
 
 import argcomplete
 from pydantic import BaseModel
-from typing_extensions import TypeAlias
 
 from datamodel_code_generator import (
     DEFAULT_SHARED_MODULE_NAME,
     AllExportsCollisionStrategy,
     AllExportsScope,
+    AllOfMergeMode,
     DataclassArguments,
     DataModelType,
     Error,
     InputFileType,
     InvalidClassNameError,
+    ModuleSplitMode,
     OpenAPIScope,
+    ReadOnlyWriteOnlyModelType,
     ReuseScope,
     enable_debug_message,
     generate,
@@ -66,15 +69,20 @@ EXCLUDED_CONFIG_OPTIONS: frozenset[str] = frozenset({
     "check",
     "generate_pyproject_config",
     "generate_cli_command",
+    "ignore_pyproject",
+    "profile",
     "version",
     "help",
     "debug",
     "no_color",
     "disable_warnings",
+    "watch",
+    "watch_delay",
 })
 
 BOOLEAN_OPTIONAL_OPTIONS: frozenset[str] = frozenset({
     "use_specialized_enum",
+    "use_standard_collections",
 })
 
 
@@ -165,7 +173,7 @@ class Config(BaseModel):
             return urlparse(value)
         if value is None:  # pragma: no cover
             return None
-        msg = f"This protocol doesn't support only http/https. --input={value}"  # pragma: no cover
+        msg = f"Unsupported URL scheme. Supported: http, https, file. --input={value}"  # pragma: no cover
         raise Error(msg)  # pragma: no cover
 
     # Pydantic 1.5.1 doesn't support each_item=True correctly
@@ -379,13 +387,14 @@ class Config(BaseModel):
     aliases: Optional[TextIOBase] = None  # noqa: UP045
     disable_timestamp: bool = False
     enable_version_header: bool = False
+    enable_command_header: bool = False
     allow_population_by_field_name: bool = False
     allow_extra_fields: bool = False
     extra_fields: Optional[str] = None  # noqa: UP045
     use_default: bool = False
     force_optional: bool = False
     class_name: Optional[str] = None  # noqa: UP045
-    use_standard_collections: bool = False
+    use_standard_collections: bool = True
     use_schema_description: bool = False
     use_field_description: bool = False
     use_attribute_docstrings: bool = False
@@ -396,13 +405,15 @@ class Config(BaseModel):
     shared_module_name: str = DEFAULT_SHARED_MODULE_NAME
     encoding: str = DEFAULT_ENCODING
     enum_field_as_literal: Optional[LiteralType] = None  # noqa: UP045
+    ignore_enum_constraints: bool = False
     use_one_literal_as_default: bool = False
+    use_enum_values_in_discriminator: bool = False
     set_default_enum_member: bool = False
     use_subclass_enum: bool = False
     use_specialized_enum: bool = True
     strict_nullable: bool = False
     use_generic_container_types: bool = False
-    use_union_operator: bool = False
+    use_union_operator: bool = True
     enable_faux_immutability: bool = False
     url: Optional[ParseResult] = None  # noqa: UP045
     disable_appending_item_suffix: bool = False
@@ -417,10 +428,13 @@ class Config(BaseModel):
     use_title_as_name: bool = False
     use_operation_id_as_name: bool = False
     use_unique_items_as_set: bool = False
+    allof_merge_mode: AllOfMergeMode = AllOfMergeMode.Constraints
     http_headers: Optional[Sequence[tuple[str, str]]] = None  # noqa: UP045
     http_ignore_tls: bool = False
     use_annotated: bool = False
+    use_serialize_as_any: bool = False
     use_non_positive_negative_number_constrained_types: bool = False
+    use_decimal_for_multiple_of: bool = False
     original_field_name_delimiter: Optional[str] = None  # noqa: UP045
     use_double_quotes: bool = False
     collapse_root_models: bool = False
@@ -444,12 +458,18 @@ class Config(BaseModel):
     frozen_dataclasses: bool = False
     dataclass_arguments: Optional[DataclassArguments] = None  # noqa: UP045
     no_alias: bool = False
+    use_frozen_field: bool = False
     formatters: list[Formatter] = DEFAULT_FORMATTERS
     parent_scoped_naming: bool = False
     disable_future_imports: bool = False
     type_mappings: Optional[list[str]] = None  # noqa: UP045
+    read_only_write_only_model_type: Optional[ReadOnlyWriteOnlyModelType] = None  # noqa: UP045
+    use_status_code_in_response_name: bool = False
     all_exports_scope: Optional[AllExportsScope] = None  # noqa: UP045
     all_exports_collision_strategy: Optional[AllExportsCollisionStrategy] = None  # noqa: UP045
+    module_split_mode: Optional[ModuleSplitMode] = None  # noqa: UP045
+    watch: bool = False
+    watch_delay: float = 0.5
 
     def merge_args(self, args: Namespace) -> None:
         """Merge command-line arguments into config."""
@@ -466,16 +486,27 @@ class Config(BaseModel):
             setattr(self, field_name, getattr(parsed_args, field_name))
 
 
-def _get_pyproject_toml_config(source: Path) -> dict[str, Any]:
-    """Find and return the [tool.datamodel-codgen] section of the closest pyproject.toml if it exists."""
+def _get_pyproject_toml_config(source: Path, profile: str | None = None) -> dict[str, Any]:
+    """Find and return the [tool.datamodel-codegen] section of the closest pyproject.toml if it exists."""
     current_path = source
     while current_path != current_path.parent:
         if (current_path / "pyproject.toml").is_file():
             pyproject_toml = load_toml(current_path / "pyproject.toml")
             if "datamodel-codegen" in pyproject_toml.get("tool", {}):
-                pyproject_config = pyproject_toml["tool"]["datamodel-codegen"]
-                # Convert options from kebap- to snake-case
-                pyproject_config = {k.replace("-", "_"): v for k, v in pyproject_config.items()}
+                tool_config = pyproject_toml["tool"]["datamodel-codegen"]
+
+                base_config: dict[str, Any] = {k: v for k, v in tool_config.items() if k != "profiles"}
+
+                if profile:
+                    profiles = tool_config.get("profiles", {})
+                    if profile not in profiles:
+                        available = list(profiles.keys()) if profiles else "none"
+                        msg = f"Profile '{profile}' not found in pyproject.toml. Available profiles: {available}"
+                        raise Error(msg)
+                    profile_config = profiles[profile]
+                    base_config.update(profile_config)
+
+                pyproject_config = {k.replace("-", "_"): v for k, v in base_config.items()}
                 # Replace US-american spelling if present (ignore if british spelling is present)
                 if (
                     "capitalize_enum_members" in pyproject_config and "capitalise_enum_members" not in pyproject_config
@@ -485,13 +516,19 @@ def _get_pyproject_toml_config(source: Path) -> dict[str, Any]:
 
         if (current_path / ".git").exists():
             # Stop early if we see a git repository root.
-            return {}
+            break
 
         current_path = current_path.parent
+
+    # If profile was requested but no pyproject.toml config was found, raise an error
+    if profile:
+        msg = f"Profile '{profile}' requested but no [tool.datamodel-codegen] section found in pyproject.toml"
+        raise Error(msg)
+
     return {}
 
 
-TomlValue: TypeAlias = Union[str, bool, list["TomlValue"], tuple["TomlValue", ...]]
+TomlValue: TypeAlias = str | bool | list["TomlValue"] | tuple["TomlValue", ...]
 
 
 def _format_toml_value(value: TomlValue) -> str:
@@ -625,6 +662,119 @@ def generate_cli_command(config: dict[str, TomlValue]) -> str:
     return " ".join(parts) + "\n"
 
 
+def run_generate_from_config(  # noqa: PLR0913, PLR0917
+    config: Config,
+    input_: Path | str | ParseResult,
+    output: Path | None,
+    extra_template_data: dict[str, Any] | None,
+    aliases: dict[str, str] | None,
+    command_line: str | None,
+    custom_formatters_kwargs: dict[str, str] | None,
+    settings_path: Path | None = None,
+) -> None:
+    """Run code generation with the given config and parameters."""
+    generate(
+        input_=input_,
+        input_file_type=config.input_file_type,
+        output=output,
+        output_model_type=config.output_model_type,
+        target_python_version=config.target_python_version,
+        base_class=config.base_class,
+        additional_imports=config.additional_imports,
+        custom_template_dir=config.custom_template_dir,
+        validation=config.validation,
+        field_constraints=config.field_constraints,
+        snake_case_field=config.snake_case_field,
+        strip_default_none=config.strip_default_none,
+        extra_template_data=extra_template_data,  # pyright: ignore[reportArgumentType]
+        aliases=aliases,
+        disable_timestamp=config.disable_timestamp,
+        enable_version_header=config.enable_version_header,
+        enable_command_header=config.enable_command_header,
+        command_line=command_line,
+        allow_population_by_field_name=config.allow_population_by_field_name,
+        allow_extra_fields=config.allow_extra_fields,
+        extra_fields=config.extra_fields,
+        apply_default_values_for_required_fields=config.use_default,
+        force_optional_for_required_fields=config.force_optional,
+        class_name=config.class_name,
+        use_standard_collections=config.use_standard_collections,
+        use_schema_description=config.use_schema_description,
+        use_field_description=config.use_field_description,
+        use_attribute_docstrings=config.use_attribute_docstrings,
+        use_inline_field_description=config.use_inline_field_description,
+        use_default_kwarg=config.use_default_kwarg,
+        reuse_model=config.reuse_model,
+        reuse_scope=config.reuse_scope,
+        shared_module_name=config.shared_module_name,
+        encoding=config.encoding,
+        enum_field_as_literal=config.enum_field_as_literal,
+        ignore_enum_constraints=config.ignore_enum_constraints,
+        use_one_literal_as_default=config.use_one_literal_as_default,
+        use_enum_values_in_discriminator=config.use_enum_values_in_discriminator,
+        set_default_enum_member=config.set_default_enum_member,
+        use_subclass_enum=config.use_subclass_enum,
+        use_specialized_enum=config.use_specialized_enum,
+        strict_nullable=config.strict_nullable,
+        use_generic_container_types=config.use_generic_container_types,
+        enable_faux_immutability=config.enable_faux_immutability,
+        disable_appending_item_suffix=config.disable_appending_item_suffix,
+        strict_types=config.strict_types,
+        empty_enum_field_name=config.empty_enum_field_name,
+        field_extra_keys=config.field_extra_keys,
+        field_include_all_keys=config.field_include_all_keys,
+        field_extra_keys_without_x_prefix=config.field_extra_keys_without_x_prefix,
+        openapi_scopes=config.openapi_scopes,
+        include_path_parameters=config.include_path_parameters,
+        wrap_string_literal=config.wrap_string_literal,
+        use_title_as_name=config.use_title_as_name,
+        use_operation_id_as_name=config.use_operation_id_as_name,
+        use_unique_items_as_set=config.use_unique_items_as_set,
+        allof_merge_mode=config.allof_merge_mode,
+        http_headers=config.http_headers,
+        http_ignore_tls=config.http_ignore_tls,
+        use_annotated=config.use_annotated,
+        use_serialize_as_any=config.use_serialize_as_any,
+        use_non_positive_negative_number_constrained_types=config.use_non_positive_negative_number_constrained_types,
+        use_decimal_for_multiple_of=config.use_decimal_for_multiple_of,
+        original_field_name_delimiter=config.original_field_name_delimiter,
+        use_double_quotes=config.use_double_quotes,
+        collapse_root_models=config.collapse_root_models,
+        skip_root_model=config.skip_root_model,
+        use_type_alias=config.use_type_alias,
+        use_union_operator=config.use_union_operator,
+        special_field_name_prefix=config.special_field_name_prefix,
+        remove_special_field_name_prefix=config.remove_special_field_name_prefix,
+        capitalise_enum_members=config.capitalise_enum_members,
+        keep_model_order=config.keep_model_order,
+        custom_file_header=config.custom_file_header,
+        custom_file_header_path=config.custom_file_header_path,
+        custom_formatters=config.custom_formatters,
+        custom_formatters_kwargs=custom_formatters_kwargs,
+        use_pendulum=config.use_pendulum,
+        http_query_parameters=config.http_query_parameters,
+        treat_dot_as_module=config.treat_dot_as_module,
+        use_exact_imports=config.use_exact_imports,
+        union_mode=config.union_mode,
+        output_datetime_class=config.output_datetime_class,
+        keyword_only=config.keyword_only,
+        frozen_dataclasses=config.frozen_dataclasses,
+        no_alias=config.no_alias,
+        use_frozen_field=config.use_frozen_field,
+        formatters=config.formatters,
+        settings_path=settings_path,
+        parent_scoped_naming=config.parent_scoped_naming,
+        dataclass_arguments=config.dataclass_arguments,
+        disable_future_imports=config.disable_future_imports,
+        type_mappings=config.type_mappings,
+        read_only_write_only_model_type=config.read_only_write_only_model_type,
+        use_status_code_in_response_name=config.use_status_code_in_response_name,
+        all_exports_scope=config.all_exports_scope,
+        all_exports_collision_strategy=config.all_exports_collision_strategy,
+        module_split_mode=config.module_split_mode,
+    )
+
+
 def main(args: Sequence[str] | None = None) -> Exit:  # noqa: PLR0911, PLR0912, PLR0914, PLR0915
     """Execute datamodel code generation from command-line arguments."""
     argcomplete.autocomplete(arg_parser)
@@ -645,7 +795,15 @@ def main(args: Sequence[str] | None = None) -> Exit:  # noqa: PLR0911, PLR0912,
         print(config_output)  # noqa: T201
         return Exit.OK
 
-    pyproject_config = _get_pyproject_toml_config(Path.cwd())
+    # Handle --ignore-pyproject and --profile options
+    if namespace.ignore_pyproject:
+        pyproject_config: dict[str, Any] = {}
+    else:
+        try:
+            pyproject_config = _get_pyproject_toml_config(Path.cwd(), profile=namespace.profile)
+        except Error as e:
+            print(e.message, file=sys.stderr)  # noqa: T201
+            return Exit.ERROR
 
     if namespace.generate_cli_command:
         if not pyproject_config:
@@ -680,6 +838,20 @@ def main(args: Sequence[str] | None = None) -> Exit:  # noqa: PLR0911, PLR0912,
         )
         return Exit.ERROR
 
+    if config.watch and config.check:
+        print(  # noqa: T201
+            "Error: --watch and --check cannot be used together",
+            file=sys.stderr,
+        )
+        return Exit.ERROR
+
+    if config.watch and (config.input is None or is_url(str(config.input))):
+        print(  # noqa: T201
+            "Error: --watch requires --input file path (not URL or stdin)",
+            file=sys.stderr,
+        )
+        return Exit.ERROR
+
     if not is_supported_in_black(config.target_python_version):  # pragma: no cover
         print(  # noqa: T201
             f"Installed black doesn't support Python version {config.target_python_version.value}.\n"
@@ -701,6 +873,20 @@ def main(args: Sequence[str] | None = None) -> Exit:  # noqa: PLR0911, PLR0912,
             file=sys.stderr,
         )
 
+    if (
+        config.use_specialized_enum
+        and namespace.use_specialized_enum is not False  # CLI didn't disable it
+        and (namespace.use_specialized_enum is True or pyproject_config.get("use_specialized_enum") is True)
+        and not config.target_python_version.has_strenum
+    ):
+        print(  # noqa: T201
+            f"Error: --use-specialized-enum requires --target-python-version 3.11 or later.\n"
+            f"Current target version: {config.target_python_version.value}\n"
+            f"StrEnum is only available in Python 3.11+.",
+            file=sys.stderr,
+        )
+        return Exit.ERROR
+
     extra_template_data: defaultdict[str, dict[str, Any]] | None
     if config.extra_template_data is None:
         extra_template_data = None
@@ -766,93 +952,15 @@ def main(args: Sequence[str] | None = None) -> Exit:  # noqa: PLR0911, PLR0912,
         is_directory_output = False
 
     try:
-        generate(
+        run_generate_from_config(
+            config=config,
             input_=config.url or config.input or sys.stdin.read(),
-            input_file_type=config.input_file_type,
             output=generate_output,
-            output_model_type=config.output_model_type,
-            target_python_version=config.target_python_version,
-            base_class=config.base_class,
-            additional_imports=config.additional_imports,
-            custom_template_dir=config.custom_template_dir,
-            validation=config.validation,
-            field_constraints=config.field_constraints,
-            snake_case_field=config.snake_case_field,
-            strip_default_none=config.strip_default_none,
             extra_template_data=extra_template_data,
             aliases=aliases,
-            disable_timestamp=config.disable_timestamp,
-            enable_version_header=config.enable_version_header,
-            allow_population_by_field_name=config.allow_population_by_field_name,
-            allow_extra_fields=config.allow_extra_fields,
-            extra_fields=config.extra_fields,
-            apply_default_values_for_required_fields=config.use_default,
-            force_optional_for_required_fields=config.force_optional,
-            class_name=config.class_name,
-            use_standard_collections=config.use_standard_collections,
-            use_schema_description=config.use_schema_description,
-            use_field_description=config.use_field_description,
-            use_attribute_docstrings=config.use_attribute_docstrings,
-            use_inline_field_description=config.use_inline_field_description,
-            use_default_kwarg=config.use_default_kwarg,
-            reuse_model=config.reuse_model,
-            reuse_scope=config.reuse_scope,
-            shared_module_name=config.shared_module_name,
-            encoding=config.encoding,
-            enum_field_as_literal=config.enum_field_as_literal,
-            use_one_literal_as_default=config.use_one_literal_as_default,
-            set_default_enum_member=config.set_default_enum_member,
-            use_subclass_enum=config.use_subclass_enum,
-            use_specialized_enum=config.use_specialized_enum,
-            strict_nullable=config.strict_nullable,
-            use_generic_container_types=config.use_generic_container_types,
-            enable_faux_immutability=config.enable_faux_immutability,
-            disable_appending_item_suffix=config.disable_appending_item_suffix,
-            strict_types=config.strict_types,
-            empty_enum_field_name=config.empty_enum_field_name,
-            field_extra_keys=config.field_extra_keys,
-            field_include_all_keys=config.field_include_all_keys,
-            field_extra_keys_without_x_prefix=config.field_extra_keys_without_x_prefix,
-            openapi_scopes=config.openapi_scopes,
-            include_path_parameters=config.include_path_parameters,
-            wrap_string_literal=config.wrap_string_literal,
-            use_title_as_name=config.use_title_as_name,
-            use_operation_id_as_name=config.use_operation_id_as_name,
-            use_unique_items_as_set=config.use_unique_items_as_set,
-            http_headers=config.http_headers,
-            http_ignore_tls=config.http_ignore_tls,
-            use_annotated=config.use_annotated,
-            use_non_positive_negative_number_constrained_types=config.use_non_positive_negative_number_constrained_types,
-            original_field_name_delimiter=config.original_field_name_delimiter,
-            use_double_quotes=config.use_double_quotes,
-            collapse_root_models=config.collapse_root_models,
-            skip_root_model=config.skip_root_model,
-            use_type_alias=config.use_type_alias,
-            use_union_operator=config.use_union_operator,
-            special_field_name_prefix=config.special_field_name_prefix,
-            remove_special_field_name_prefix=config.remove_special_field_name_prefix,
-            capitalise_enum_members=config.capitalise_enum_members,
-            keep_model_order=config.keep_model_order,
-            custom_file_header=config.custom_file_header,
-            custom_file_header_path=config.custom_file_header_path,
-            custom_formatters=config.custom_formatters,
+            command_line=shlex.join(["datamodel-codegen", *args]) if config.enable_command_header else None,
             custom_formatters_kwargs=custom_formatters_kwargs,
-            use_pendulum=config.use_pendulum,
-            http_query_parameters=config.http_query_parameters,
-            treat_dot_as_module=config.treat_dot_as_module,
-            use_exact_imports=config.use_exact_imports,
-            union_mode=config.union_mode,
-            output_datetime_class=config.output_datetime_class,
-            keyword_only=config.keyword_only,
-            frozen_dataclasses=config.frozen_dataclasses,
-            no_alias=config.no_alias,
-            formatters=config.formatters,
-            parent_scoped_naming=config.parent_scoped_naming,
-            dataclass_arguments=config.dataclass_arguments,
-            disable_future_imports=config.disable_future_imports,
-            type_mappings=config.type_mappings,
-            all_exports_scope=config.all_exports_scope,
-            all_exports_collision_strategy=config.all_exports_collision_strategy,
+            settings_path=config.output if config.check else None,
         )
     except InvalidClassNameError as e:
         print(f"{e} You have to set `--class-name` option", file=sys.stderr)  # noqa: T201
@@ -897,6 +1005,15 @@ def main(args: Sequence[str] | None = None) -> Exit:  # noqa: PLR0911, PLR0912,
 
         return Exit.DIFF if has_differences else Exit.OK
 
+    if config.watch:
+        try:
+            from datamodel_code_generator.watch import watch_and_regenerate  # noqa: PLC0415
+
+            return watch_and_regenerate(config, extra_template_data, aliases, custom_formatters_kwargs)
+        except Exception as e:  # noqa: BLE001
+            print(str(e), file=sys.stderr)  # noqa: T201
+            return Exit.ERROR
+
     return Exit.OK
 
 
