@@ -8,21 +8,25 @@ from __future__ import annotations
 
 import re
 from collections import defaultdict
+from contextlib import nullcontext
 from enum import Enum
+from pathlib import Path
 from re import Pattern
-from typing import TYPE_CHECKING, Any, Callable, ClassVar, Optional, TypeVar, Union
+from typing import TYPE_CHECKING, Any, ClassVar, Optional, TypeVar, Union
 from warnings import warn
 
 from pydantic import Field
 
 from datamodel_code_generator import (
     DEFAULT_SHARED_MODULE_NAME,
+    AllOfMergeMode,
     DataclassArguments,
     Error,
     LiteralType,
     OpenAPIScope,
     PythonVersion,
     PythonVersionMin,
+    ReadOnlyWriteOnlyModelType,
     ReuseScope,
     YamlValue,
     load_yaml_dict,
@@ -37,7 +41,7 @@ from datamodel_code_generator.parser.jsonschema import (
     JsonSchemaParser,
     get_model_by_path,
 )
-from datamodel_code_generator.reference import FieldNameResolver, snake_to_upper_camel
+from datamodel_code_generator.reference import FieldNameResolver, is_url, snake_to_upper_camel
 from datamodel_code_generator.types import (
     DataType,
     DataTypeManager,
@@ -47,8 +51,7 @@ from datamodel_code_generator.types import (
 from datamodel_code_generator.util import BaseModel
 
 if TYPE_CHECKING:
-    from collections.abc import Iterable, Mapping, Sequence
-    from pathlib import Path
+    from collections.abc import Callable, Iterable, Mapping, Sequence
     from urllib.parse import ParseResult
 
     from datamodel_code_generator.parser import DefaultPutDict
@@ -211,7 +214,9 @@ class OpenAPIParser(JsonSchemaParser):
         shared_module_name: str = DEFAULT_SHARED_MODULE_NAME,
         encoding: str = "utf-8",
         enum_field_as_literal: LiteralType | None = None,
+        ignore_enum_constraints: bool = False,
         use_one_literal_as_default: bool = False,
+        use_enum_values_in_discriminator: bool = False,
         set_default_enum_member: bool = False,
         use_subclass_enum: bool = False,
         use_specialized_enum: bool = True,
@@ -232,10 +237,13 @@ class OpenAPIParser(JsonSchemaParser):
         use_title_as_name: bool = False,
         use_operation_id_as_name: bool = False,
         use_unique_items_as_set: bool = False,
+        allof_merge_mode: AllOfMergeMode = AllOfMergeMode.Constraints,
         http_headers: Sequence[tuple[str, str]] | None = None,
         http_ignore_tls: bool = False,
         use_annotated: bool = False,
+        use_serialize_as_any: bool = False,
         use_non_positive_negative_number_constrained_types: bool = False,
+        use_decimal_for_multiple_of: bool = False,
         original_field_name_delimiter: str | None = None,
         use_double_quotes: bool = False,
         use_union_operator: bool = False,
@@ -263,6 +271,9 @@ class OpenAPIParser(JsonSchemaParser):
         parent_scoped_naming: bool = False,
         dataclass_arguments: DataclassArguments | None = None,
         type_mappings: list[str] | None = None,
+        read_only_write_only_model_type: ReadOnlyWriteOnlyModelType | None = None,
+        use_frozen_field: bool = False,
+        use_status_code_in_response_name: bool = False,
     ) -> None:
         """Initialize the OpenAPI parser with extensive configuration options."""
         target_datetime_class = target_datetime_class or DatetimeClassType.Awaredatetime
@@ -301,7 +312,9 @@ class OpenAPIParser(JsonSchemaParser):
             shared_module_name=shared_module_name,
             encoding=encoding,
             enum_field_as_literal=enum_field_as_literal,
+            ignore_enum_constraints=ignore_enum_constraints,
             use_one_literal_as_default=use_one_literal_as_default,
+            use_enum_values_in_discriminator=use_enum_values_in_discriminator,
             set_default_enum_member=set_default_enum_member,
             use_subclass_enum=use_subclass_enum,
             use_specialized_enum=use_specialized_enum,
@@ -320,10 +333,13 @@ class OpenAPIParser(JsonSchemaParser):
             use_title_as_name=use_title_as_name,
             use_operation_id_as_name=use_operation_id_as_name,
             use_unique_items_as_set=use_unique_items_as_set,
+            allof_merge_mode=allof_merge_mode,
             http_headers=http_headers,
             http_ignore_tls=http_ignore_tls,
             use_annotated=use_annotated,
+            use_serialize_as_any=use_serialize_as_any,
             use_non_positive_negative_number_constrained_types=use_non_positive_negative_number_constrained_types,
+            use_decimal_for_multiple_of=use_decimal_for_multiple_of,
             original_field_name_delimiter=original_field_name_delimiter,
             use_double_quotes=use_double_quotes,
             use_union_operator=use_union_operator,
@@ -351,9 +367,12 @@ class OpenAPIParser(JsonSchemaParser):
             parent_scoped_naming=parent_scoped_naming,
             dataclass_arguments=dataclass_arguments,
             type_mappings=type_mappings,
+            read_only_write_only_model_type=read_only_write_only_model_type,
+            use_frozen_field=use_frozen_field,
         )
         self.open_api_scopes: list[OpenAPIScope] = openapi_scopes or [OpenAPIScope.Schemas]
         self.include_path_parameters: bool = include_path_parameters
+        self.use_status_code_in_response_name: bool = use_status_code_in_response_name
         self._discriminator_schemas: dict[str, dict[str, Any]] = {}
         self._discriminator_subtypes: dict[str, list[str]] = defaultdict(list)
 
@@ -425,6 +444,67 @@ class OpenAPIParser(JsonSchemaParser):
             return object_type.parse_obj(ref_obj)
         return obj
 
+    def _parse_schema_or_ref(
+        self,
+        name: str,
+        schema: JsonSchemaObject | ReferenceObject | None,
+        path: list[str],
+    ) -> DataType | None:
+        """Parse a schema object or resolve a reference to get DataType."""
+        if schema is None:
+            return None
+        if isinstance(schema, JsonSchemaObject):
+            return self.parse_schema(name, schema, path)
+        self.resolve_ref(schema.ref)
+        return self.get_ref_data_type(schema.ref)
+
+    def _process_path_items(  # noqa: PLR0913
+        self,
+        items: dict[str, dict[str, Any]],
+        base_path: list[str],
+        scope_name: str,
+        global_parameters: list[dict[str, Any]],
+        security: list[dict[str, list[str]]] | None,
+        *,
+        strip_leading_slash: bool = True,
+    ) -> None:
+        """Process path or webhook items with operations."""
+        scope_path = [*base_path, f"#/{scope_name}"]
+        for item_name, methods_ in items.items():
+            item_ref = methods_.get("$ref")
+            if item_ref:
+                methods = self.get_ref_model(item_ref)
+                # Extract base path from reference for external file resolution
+                resolved_ref = self.model_resolver.resolve_ref(item_ref)
+                ref_file = resolved_ref.split("#")[0] if "#" in resolved_ref else resolved_ref
+                ref_base_path = Path(ref_file).parent if ref_file and not is_url(ref_file) else None
+            else:
+                methods = methods_
+                ref_base_path = None
+
+            item_parameters = global_parameters.copy()
+            if "parameters" in methods:
+                item_parameters.extend(methods["parameters"])
+
+            relative_name = item_name[1:] if strip_leading_slash else item_name.removeprefix("/")
+            path = [*scope_path, relative_name] if relative_name else get_special_path("root", scope_path)
+
+            base_path_context = (
+                self.model_resolver.current_base_path_context(ref_base_path) if ref_base_path else nullcontext()
+            )
+            with base_path_context:
+                for operation_name, raw_operation in methods.items():
+                    if operation_name not in OPERATION_NAMES:
+                        continue
+                    if item_parameters:
+                        if "parameters" in raw_operation:
+                            raw_operation["parameters"].extend(item_parameters)
+                        else:
+                            raw_operation["parameters"] = item_parameters.copy()
+                    if security is not None and "security" not in raw_operation:
+                        raw_operation["security"] = security
+                    self.parse_operation(raw_operation, [*path, operation_name])
+
     def parse_schema(
         self,
         name: str,
@@ -442,7 +522,7 @@ class OpenAPIParser(JsonSchemaParser):
                 self.parse_object(name, obj, path)
         elif obj.is_object:
             data_type = self.parse_object(name, obj, path)
-        elif obj.enum:  # pragma: no cover
+        elif obj.enum and not self.ignore_enum_constraints:  # pragma: no cover
             data_type = self.parse_enum(name, obj, path)
         elif obj.ref:  # pragma: no cover
             data_type = self.get_ref_data_type(obj.ref)
@@ -459,15 +539,10 @@ class OpenAPIParser(JsonSchemaParser):
     ) -> dict[str, DataType]:
         """Parse request body content into data types by media type."""
         data_types: dict[str, DataType] = {}
-        for (
-            media_type,
-            media_obj,
-        ) in request_body.content.items():
-            if isinstance(media_obj.schema_, JsonSchemaObject):
-                data_types[media_type] = self.parse_schema(name, media_obj.schema_, [*path, media_type])
-            elif media_obj.schema_ is not None:
-                self.resolve_ref(media_obj.schema_.ref)
-                data_types[media_type] = self.get_ref_data_type(media_obj.schema_.ref)
+        for media_type, media_obj in request_body.content.items():
+            data_type = self._parse_schema_or_ref(name, media_obj.schema_, [*path, media_type])
+            if data_type:
+                data_types[media_type] = data_type
         return data_types
 
     def parse_responses(
@@ -479,6 +554,8 @@ class OpenAPIParser(JsonSchemaParser):
         """Parse response objects into data types by status code and content type."""
         data_types: defaultdict[str | int, dict[str, DataType]] = defaultdict(dict)
         for status_code, detail in responses.items():
+            response_name = f"{name}{str(status_code).capitalize()}" if self.use_status_code_in_response_name else name
+
             if isinstance(detail, ReferenceObject):
                 if not detail.ref:  # pragma: no cover
                     continue
@@ -491,20 +568,10 @@ class OpenAPIParser(JsonSchemaParser):
                 data_types[status_code]["application/json"] = DataType(type="None")
 
             for content_type, obj in content.items():
-                object_schema = obj.schema_
-                if not object_schema:  # pragma: no cover
-                    continue
-                if isinstance(object_schema, JsonSchemaObject):
-                    data_types[status_code][content_type] = self.parse_schema(  # pyright: ignore[reportArgumentType]
-                        name,
-                        object_schema,
-                        [*path, str(status_code), content_type],  # pyright: ignore[reportArgumentType]
-                    )
-                else:
-                    self.resolve_ref(object_schema.ref)
-                    data_types[status_code][content_type] = self.get_ref_data_type(  # pyright: ignore[reportArgumentType]
-                        object_schema.ref
-                    )
+                response_path: list[str] = [*path, str(status_code), str(content_type)]
+                data_type = self._parse_schema_or_ref(response_name, obj.schema_, response_path)
+                if data_type:
+                    data_types[status_code][content_type] = data_type  # pyright: ignore[reportArgumentType]
 
         return data_types
 
@@ -553,6 +620,7 @@ class OpenAPIParser(JsonSchemaParser):
             field_name, alias = self.model_resolver.get_valid_field_name_and_alias(
                 field_name=parameter_name,
                 excludes=exclude_field_names,
+                model_type=self.field_name_model_type,
                 class_name=name,
             )
             if parameter.schema_:
@@ -608,6 +676,7 @@ class OpenAPIParser(JsonSchemaParser):
                         strip_default_none=self.strip_default_none,
                         extras=self.get_field_extras(object_schema) if object_schema else {},
                         use_annotated=self.use_annotated,
+                        use_serialize_as_any=self.use_serialize_as_any,
                         use_field_description=self.use_field_description,
                         use_inline_field_description=self.use_inline_field_description,
                         use_default_kwarg=self.use_default_kwarg,
@@ -682,9 +751,9 @@ class OpenAPIParser(JsonSchemaParser):
                 path=[*path, "tags"],
             )
 
-    def parse_raw(self) -> None:  # noqa: PLR0912, PLR0915
+    def parse_raw(self) -> None:
         """Parse OpenAPI specification including schemas, paths, and operations."""
-        for source, path_parts in self._get_context_source_path_parts():  # noqa: PLR1702
+        for source, path_parts in self._get_context_source_path_parts():
             if self.validation:
                 warn(
                     "Deprecated: `--validation` option is deprecated. the option will be removed in a future "
@@ -713,7 +782,15 @@ class OpenAPIParser(JsonSchemaParser):
             self.raw_obj = specification
             self._collect_discriminator_schemas()
             schemas: dict[str, Any] = specification.get("components", {}).get("schemas", {})
+            paths: dict[str, Any] = specification.get("paths", {})
             security: list[dict[str, list[str]]] | None = specification.get("security")
+            # Warn if schemas is empty but paths exist and only Schemas scope is used
+            if not schemas and self.open_api_scopes == [OpenAPIScope.Schemas] and paths:
+                warn(
+                    "No schemas found in components/schemas. If your schemas are defined in "
+                    "external files referenced from paths, consider using --openapi-scopes paths",
+                    stacklevel=2,
+                )
             if OpenAPIScope.Schemas in self.open_api_scopes:
                 for obj_name, raw_obj in schemas.items():
                     self.parse_raw_obj(
@@ -722,70 +799,17 @@ class OpenAPIParser(JsonSchemaParser):
                         [*path_parts, "#/components", "schemas", obj_name],
                     )
             if OpenAPIScope.Paths in self.open_api_scopes:
-                paths: dict[str, Any] = specification.get("paths", {})
-                parameters: list[dict[str, Any]] = [
-                    self._get_ref_body(p["$ref"]) if "$ref" in p else p
+                # Resolve $ref in global parameter list
+                global_parameters = [
+                    self._get_ref_body(p["$ref"]) if isinstance(p, dict) and "$ref" in p else p
                     for p in paths.get("parameters", [])
                     if isinstance(p, dict)
                 ]
-                paths_path = [*path_parts, "#/paths"]
-                for path_name, methods_ in paths.items():
-                    # Resolve path items if applicable
-                    methods = self.get_ref_model(methods_["$ref"]) if "$ref" in methods_ else methods_
-                    paths_parameters = parameters.copy()
-                    if "parameters" in methods:
-                        paths_parameters.extend(methods["parameters"])
-                    relative_path_name = path_name[1:]
-                    if relative_path_name:
-                        path = [*paths_path, relative_path_name]
-                    else:  # pragma: no cover
-                        path = get_special_path("root", paths_path)
-                    for operation_name, raw_operation in methods.items():
-                        if operation_name not in OPERATION_NAMES:
-                            continue
-                        if paths_parameters:
-                            if "parameters" in raw_operation:  # pragma: no cover
-                                raw_operation["parameters"].extend(paths_parameters)
-                            else:
-                                raw_operation["parameters"] = paths_parameters
-                        if security is not None and "security" not in raw_operation:
-                            raw_operation["security"] = security
-                        self.parse_operation(
-                            raw_operation,
-                            [*path, operation_name],
-                        )
+                self._process_path_items(paths, path_parts, "paths", global_parameters, security)
 
             if OpenAPIScope.Webhooks in self.open_api_scopes:
                 webhooks: dict[str, dict[str, Any]] = specification.get("webhooks", {})
-                webhooks_path = [*path_parts, "#/webhooks"]
-                for webhook_name, methods_ in webhooks.items():
-                    methods = self.get_ref_model(methods_["$ref"]) if "$ref" in methods_ else methods_
-                    webhook_parameters: list[dict[str, Any]] = []
-                    if "parameters" in methods:
-                        webhook_parameters = [
-                            self._get_ref_body(p["$ref"]) if "$ref" in p else p
-                            for p in methods["parameters"]
-                            if isinstance(p, dict)
-                        ]
-                    relative_webhook_name = webhook_name.removeprefix("/")
-                    if relative_webhook_name:
-                        path = [*webhooks_path, relative_webhook_name]
-                    else:  # pragma: no cover
-                        path = get_special_path("root", webhooks_path)
-                    for operation_name, raw_operation in methods.items():
-                        if operation_name not in OPERATION_NAMES:
-                            continue
-                        if webhook_parameters:
-                            if "parameters" in raw_operation:
-                                raw_operation["parameters"].extend(webhook_parameters)
-                            else:
-                                raw_operation["parameters"] = webhook_parameters.copy()
-                        if security is not None and "security" not in raw_operation:
-                            raw_operation["security"] = security
-                        self.parse_operation(
-                            raw_operation,
-                            [*path, operation_name],
-                        )
+                self._process_path_items(webhooks, path_parts, "webhooks", [], security, strip_leading_slash=False)
 
         self._resolve_unparsed_json_pointer()
 
