@@ -4,11 +4,10 @@ Custom module docstring header.
 This is a multi-line docstring used for testing.
 """
 
-
 from __future__ import annotations
 
 from enum import Enum
-from typing import Any, Dict, List, Optional, Union
+from typing import Any
 
 from pydantic import BaseModel
 
@@ -22,15 +21,15 @@ class Species(Enum):
 class Pet(BaseModel):
     id: int
     name: str
-    tag: Optional[str] = None
-    species: Optional[Species] = None
+    tag: str | None = None
+    species: Species | None = None
 
 
 class User(BaseModel):
     id: int
     name: str
-    tag: Optional[str] = None
+    tag: str | None = None
 
 
 class Event(BaseModel):
-    name: Optional[Union[str, float, int, bool, Dict[str, Any], List[str]]] = None
+    name: str | float | int | bool | dict[str, Any] | list[str] | None = None
